==> open-sysclone_0.2.tar.gz: open-sysclone-0.2/open-sysclone-gui.install/usr/share/open-sysclone-gui/js/make_image.js <==
/* Class definition*/
function MakeImageManager(){
	var self = this;
	this.BindLoginEventHandlers = function(){
		$("#goback").bind('click',this.goback);
		$("#makeimage").bind('click',this.makeimage);
	}

	this.goback = function (event){
		window.location='main.html';
	}

	this.makeimage = function (){
		var imgname = $("#imgname").val();
		var imagehdd = $("#imagehdd").val();
		var finaloperation = $("#finaloperation").val();
		var pathfile = 'imagenes';
		if (imgname === ""){
			console.log("Falta el nombre");
			return false;
		}
		if (imagehdd === ""){
			console.log("Falta el disco duro");
			return false;
		}


		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'check_path',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",pathfile],
				success: function(response,status,jqXHR){
					
					result=response[0][0];
					if (result){
						self.nfs_export_start(imgname,imagehdd,finaloperation,pathfile);
					}
					else{
						console.log("ha habido un error en la primera",response[0]);
					}
					
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});
	}


	this.nfs_export_start = function (imgnamer,imagehddr,finaloperationr,pathfilen){

		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'nfs_export_start',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",pathfilen],
				success: function(response,status,jqXHR){
					result=response[0][0];
					if (result){
						self.write_menu_pxe(imgnamer,imagehddr,finaloperationr,pathfilen);
					}
					else{
						console.log("ha habido un error en la primera",response[0]);
					}
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});


	}

	this.write_menu_pxe = function (name,hdd,finaloperations,pathfiles){
		
		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'write_menu_pxe',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",'SaveImage.tpl',pathfiles,name,hdd,finaloperations],
				success: function(response,status,jqXHR){
					//vacio la variable que me informara del resultado
					$('#result').empty();

					result=response[0][0];
					if (result){
						console.log("todo ha ido bien");
						var img = $(document.createElement('img')).attr('src','img/ok.png');
					}
					else{
						console.log("ha habido un error",response[0]);
						var img = $(document.createElement('img')).attr('src','img/fail.png');
					}
					//Añado los valores al identificador que me mostrara la respuesta por pantalla
					//Especificamos el tamaño de la imagen
					img.attr('style',"width: 15px; height: 15px; margin: 5px;");
					//añado a la variable text la respuesta de N4D
					var text = $(document.createElement('span')).html(response[0][1]);
					//Uno la imagen y el texto dentro del identificador de la web result
					$('#result').append(img);
					$('#result').append(text);
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});
	}
}

$(document).ready(function() {
	var mim = new MakeImageManager();
	mim.BindLoginEventHandlers();
});

==> open-sysclone_0.47.tar.gz: open-sysclone-0.47/open-sysclone-gui.install/usr/share/open-sysclone-gui/js/make_image.js <==
/* Class definition*/
function MakeImageManager(){
	var self = this;
	this.BindLoginEventHandlers = function(){
		$("#goback").bind('click',this.goback);
		$("#makeimage").bind('click',this.makeimage);
	}

	this.goback = function (event){
		window.location='main.html';
	}

	this.makeimage = function (){
		var imgname = $("#imgname").val();
		var imagehdd = $("#imagehdd").val();
		var finaloperation = $("#finaloperation").val();
		var pathfile = 'imagenes';
		if (imgname === ""){
			console.log("Falta el nombre");
			$('#result').empty();
			var img = $(document.createElement('img')).attr('src','img/fail.png');
			//Añado los valores al identificador que me mostrara la respuesta por pantalla
			//Especificamos el tamaño de la imagen
			img.attr('style',"width: 15px; height: 15px; margin: 5px;");
			//añado a la variable text la respuesta de N4D
			var text =  document.createTextNode("You don't tell my the name to make image");
			//Uno la imagen y el texto dentro del identificador de la web result
			$('#result').append(img);
			$('#result').append(text);
			return false;
		}
		if (imagehdd === ""){
			console.log("Falta el disco duro");
			$('#result').empty();
			var img = $(document.createElement('img')).attr('src','img/fail.png');
			//Añado los valores al identificador que me mostrara la respuesta por pantalla
			//Especificamos el tamaño de la imagen
			img.attr('style',"width: 15px; height: 15px; margin: 5px;");
			//añado a la variable text la respuesta de N4D
			var text =  document.createTextNode("You don't tell my the the HDD to make image");
			//Uno la imagen y el texto dentro del identificador de la web result
			$('#result').append(img);
			$('#result').append(text);
			return false;
		}


		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'check_path',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",pathfile],
				success: function(response,status,jqXHR){
					
					result=response[0][0];
					if (result){
						self.nfs_export_start(imgname,imagehdd,finaloperation,pathfile);
					}
					else{
						console.log("ha habido un error en la primera",response[0]);
					}
					
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});
	}


	this.nfs_export_start = function (imgnamer,imagehddr,finaloperationr,pathfilen){

		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'nfs_export_start',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",pathfilen],
				success: function(response,status,jqXHR){
					result=response[0][0];
					if (result){
						self.write_menu_pxe(imgnamer,imagehddr,finaloperationr,pathfilen);
					}
					else{
						console.log("ha habido un error en la primera",response[0]);
					}
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});


	}

	this.write_menu_pxe = function (name,hdd,finaloperations,pathfiles){
		
		$.xmlrpc({
				url: 'https://'+sessionStorage.server+':9779',
				methodName: 'write_menu_pxe',
				params: [[sessionStorage.username , sessionStorage.password],"OpenSysClone",'SaveImage.tpl',pathfiles,name,hdd,finaloperations],
				success: function(response,status,jqXHR){
					//vacio la variable que me informara del resultado
					$('#result').empty();

					result=response[0][0];
					if (result){
						console.log("todo ha ido bien");
						var img = $(document.createElement('img')).attr('src','img/ok.png');
					}
					else{
						console.log("ha habido un error",response[0]);
						var img = $(document.createElement('img')).attr('src','img/fail.png');
					}
					//Añado los valores al identificador que me mostrara la respuesta por pantalla
					//Especificamos el tamaño de la imagen
					img.attr('style',"width: 15px; height: 15px; margin: 5px;");
					//añado a la variable text la respuesta de N4D
					var text = $(document.createElement('span')).html(response[0][1]);
					//Uno la imagen y el texto dentro del identificador de la web result
					$('#result').append(img);
					$('#result').append(text);
				},
				error: function(jqXHR, status, error) {
					alert("Status: "+status+"\nError: N4d server is down"+error);
				}
			});
	}
}

$(document).ready(function() {
	var mim = new MakeImageManager();
	mim.BindLoginEventHandlers();
});
